0.2.24 (2023-11-25)
-------------------

Responsive images using the `picture` element and some smaller fixes.

- Make title link to detail and strip dash from date link in bootstrap4
  template thanks @neingeist
- Re-added the `o` ordering parameter to make it possible to order by
  visible date
- Upgraded Python Version for GitHub Actions to 3.12
- #108 Fixed test coverage for `cast/filters.py`
- #109 Responsive images revisited
  - picture element and avif format for images
  - images now have an `alt` attribute
  - using `srcset` in combination with `sizes` attributes for smaller images
  - removed `wagtail_srcset` dependency
- #110 Fixed mypy errors by putting a workaround in place
